@@ -25,7 +25,7 @@ from boto3.resources.base import ServiceResource as AWSServiceResource
 from colorama import init as colorama_init
 from tqdm import tqdm
 
-VERSION = "4.0.0"
+VERSION = "4.1.0"
 
 VALID_ACLS = [
     "private",
@@ -45,9 +45,11 @@ MIMETYPES = {
     "font/woff": [".woff"],
     "font/woff2": [".woff2"],
     "image/apng": [".apng"],
+    "image/avif": [".avif"],
     "image/bmp": [".bmp"],
     "image/gif": [".gif"],
     "image/jpeg": [".jpeg", ".jpg", ".jfif", ".pjpeg", ".pjp"],
+    "image/jxl": [".jxl"],
     "image/png": [".png"],
     "image/svg+xml": [".svg"],
     "image/tiff": [".tif", ".tiff"],
